@@ -76,7 +76,11 @@ class PossessionTime (object):
     """
     def __init__(self, clock):
         self.clock = clock
-        self.minutes, self.seconds = map(int, self.clock.split(':'))
+
+        try:
+            self.minutes, self.seconds = map(int, self.clock.split(':'))
+        except ValueError:
+            self.minutes, self.seconds = 0, 0
 
     def total_seconds(self):
         """
@@ -123,6 +127,8 @@ class GameClock (object):
             self.__minutes, self.__seconds = map(int, self.clock.split(':'))
         except ValueError:
             self.__minutes, self.__seconds = 0, 0
+        except AttributeError:
+            self.__minutes, self.__seconds = 0, 0
         try:
             self.__qtr = int(self.qtr)
             if self.__qtr >= 3:
@@ -723,7 +729,7 @@ def _get_json_data(eid=None, fpath=None):
     if os.access(fpath, os.R_OK):
         return gzip.open(fpath).read()
     try:
-        return urllib2.urlopen(_json_base_url % (eid, eid)).read()
+        return urllib2.urlopen(_json_base_url % (eid, eid), timeout=5).read()
     except urllib2.HTTPError:
         pass
     return None
